@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,10 +8,11 @@
 
 #include <QWidget>
 
-#include <KContacts/Addressee>
 #include "grantleethemeeditor/previewwidget.h"
+#include <KContacts/Addressee>
 
-namespace KAddressBookGrantlee {
+namespace KAddressBookGrantlee
+{
 }
 class QWebEngineView;
 
