@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QStringList>
 
-namespace DefaultCompletion {
+namespace DefaultCompletion
+{
 Q_REQUIRED_RESULT QStringList defaultCompetion();
 Q_REQUIRED_RESULT QStringList defaultOptions();
 }
