@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,12 +12,14 @@
 
 class QTabWidget;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ContactViewer;
 class ContactGroupViewer;
 }
 
-namespace KAddressBookGrantlee {
+namespace KAddressBookGrantlee
+{
 class GrantleeContactFormatter;
 class GrantleeContactGroupFormatter;
 }
