@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,8 @@
 class ThemeTemplateWidget;
 class EditorWidget;
 class QSplitter;
-namespace GrantleeThemeEditor {
+namespace GrantleeThemeEditor
+{
 class EditorWidget;
 class PreviewWidget;
 }
